@@ -4,8 +4,11 @@
 :mod:`pcapkit.warnings` refined built-in warnings.
 
 """
+import warnings
 
 __all__ = [
+    'warn',
+
     # UserWarning
     'BaseWarning',
     # ImportWarning
@@ -17,6 +20,22 @@ __all__ = [
     'DPKTWarning', 'ScapyWarning', 'PySharkWarning'
 ]
 
+
+def warn(message, category, stacklevel=None):
+    """Wrapper function of :func:`warnings.warn`.
+
+    Args:
+        message (Union[str, Warning]): Warning message.
+        category (Type[Warning]): Warning category.
+        stacklevel (Optional[int]): Warning stack level.
+
+    """
+    from pcapkit.utilities.exceptions import stacklevel as stacklevel_calculator  # pylint: disable=import-outside-toplevel
+    if stacklevel is None:
+        stacklevel = stacklevel_calculator()
+    warnings.warn(message, category, stacklevel)
+
+
 ##############################################################################
 # BaseWarning (abc of warnings) session.
 ##############################################################################
@@ -29,6 +48,10 @@ class BaseWarning(UserWarning):
         # warnings.simplefilter('default')
         super().__init__(*args, **kwargs)
 
+        # log warning
+        from pcapkit.utilities.logging import logger  # pylint: disable=import-outside-toplevel
+        logger.warning(str(self), exc_info=self)
+
 
 ##############################################################################
 # ImportWarning session.
